==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/module/celeborn.pl <==
#============================================================================================================
#
#	ߋOǗW[(CELEBORN)
#	celeborn.pl
#	-------------------------------------------------------------------------------------
#	2003.01.22 start
#	2003.03.07 Make\bhǉ
#	2004.08.24 č\z
#
#============================================================================================================
package	CELEBORN;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (%KAKO, $PATH, $obj);
	
	$obj = {
		'KEY'		=> undef,
		'SUBJECT'	=> undef,
		'DATE'		=> undef,
		'PATH'		=> undef
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOt@Cǂݍ
#	-------------------------------------------------------------------------------------
#	@param	$SYS	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($SYS) = @_;
	my (@elem, $path);
	
	undef $this->{'KEY'};
	undef $this->{'SUBJECT'};
	undef $this->{'DATE'};
	undef $this->{'PATH'};
	
	$path = $SYS->Get('BBSPATH') . '/' . $SYS->Get('BBS') . '/kako/kako.idx';
	
	if (-e $path) {
		open KAKO, "< $path";
		while (<KAKO>) {
			chomp $_;
			@elem = split(/<>/, $_);
			$this->{'KEY'}->{$elem[0]}		= $elem[1];
			$this->{'SUBJECT'}->{$elem[0]}	= $elem[2];
			$this->{'DATE'}->{$elem[0]}		= $elem[3];
			$this->{'PATH'}->{$elem[0]}		= $elem[4];
		}
		close KAKO;
		return 0;
	}
	return -1;
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOt@C
#	-------------------------------------------------------------------------------------
#	@param	$SYS	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($SYS) = @_;
	my ($path, $data);
	
	$path = $SYS->Get('BBSPATH') . '/' . $SYS->Get('BBS') . '/kako/kako.idx';
	
#	eval
	{
		open KAKO, "> $path";
		flock KAKO, 2;
		binmode KAKO;
		#truncate KAKO, 0;
		#seek KAKO, 0, 0;
		foreach (keys %{$this->{'SUBJECT'}}) {
			$data = join('<>',
				$_,
				$this->{KEY}->{$_},
				$this->{SUBJECT}->{$_},
				$this->{DATE}->{$_},
				$this->{PATH}->{$_}
			);
			
			print KAKO "$data\n";
		}
		close KAKO;
		chmod $SYS->Get('PM-DAT'), $path;
	};
}

#------------------------------------------------------------------------------------------------------------
#
#	IDZbg擾
#	-------------------------------------------------------------------------------------
#	@param	$kind	
#	@param	$name	[h
#	@param	$pBuf	IDZbgi[obt@
#	@return	L[Zbg
#
#------------------------------------------------------------------------------------------------------------
sub GetKeySet
{
	my $this = shift;
	my ($kind, $name, $pBuf) = @_;
	my ($key, $n);
	
	$n = 0;
	
	if ($kind eq 'ALL') {
		foreach $key (keys %{$this->{'KEY'}}) {
			if ($this->{'KEY'}->{$key} ne '0') {
				push @$pBuf, $key;
				$n++;
			}
		}
	}
	else {
		foreach $key (keys %{$this->{$kind}}) {
			if ($this->{$kind}->{$key} eq $name || $kind eq 'ALL') {
				push @$pBuf, $key;
				$n++;
			}
		}
	}
	
	return $n;
}

#------------------------------------------------------------------------------------------------------------
#
#	擾
#	-------------------------------------------------------------------------------------
#	@param	$kind	
#	@param	$key	[UID
#			$default : ftHg
#	@return	[U
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($kind, $key, $default) = @_;
	my ($val);
	
	$val = $this->{$kind}->{$key};
	
	return (defined $val ? $val : (defined $default ? $default : undef));
}

#------------------------------------------------------------------------------------------------------------
#
#	ǉ
#	-------------------------------------------------------------------------------------
#	@param	$key		XbhL[
#	@param	$subject	Xbh^Cg
#	@param	$date		XV
#	@return	ID
#
#------------------------------------------------------------------------------------------------------------
sub Add
{
	my $this = shift;
	my ($key, $subject, $date, $path) = @_;
	my ($id);
	
	$id = time;
	while (exists $this->{'KEY'}->{$id}) {
		$id++;
	}
	$this->{'KEY'}->{$id}		= $key;
	$this->{'SUBJECT'}->{$id}	= $subject;
	$this->{'DATE'}->{$id}		= $date;
	$this->{'PATH'}->{$id}		= $path;
	
	return $id;
}

#------------------------------------------------------------------------------------------------------------
#
#	ݒ
#	-------------------------------------------------------------------------------------
#	@param	$id		ID
#	@param	$kind	
#	@param	$val	ݒl
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($id, $kind, $val) = @_;
	
	if (exists $this->{$kind}->{$id}) {
		$this->{$kind}->{$id} = $val;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	폜
#	-------------------------------------------------------------------------------------
#	@param	$id		폜ID
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Delete
{
	my $this = shift;
	my ($id) = @_;
	
	delete $this->{'KEY'}->{$id};
	delete $this->{'SUBJECT'}->{$id};
	delete $this->{'DATE'}->{$id};
	delete $this->{'PATH'}->{$id};
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋO̍XV
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub UpdateInfo
{
	my $this = shift;
	my ($Sys) = @_;
	my (%Dirs, @dirList, @fileList, @elem);
	my ($dir, $file, $path, $subj);
	
	require './module/earendil.pl';
	
	undef $this->{'KEY'};
	undef $this->{'SUBJECT'};
	undef $this->{'DATE'};
	undef $this->{'PATH'};
	
	$path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . '/kako';
	
	# fBNg擾
	EARENDIL::GetFolderHierarchy($path, \%Dirs);
	EARENDIL::GetFolderList(\%Dirs, \@dirList, '');
	
	foreach $dir (@dirList) {
		EARENDIL::GetFileList("$path/$dir", \@fileList, '(\d+)\.html');
		Add($this, 0, 0, 0, $dir);
		foreach $file (@fileList) {
			@elem = split(/\./, $file);
			$subj = GetThreadSubject("$path/$dir/$file");
			if ($subj ne '') {
				Add($this, $elem[0], $subj, time, $dir);
			}
		}
		undef @fileList;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOindex̍XV
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub UpdateIndex
{
	my $this = shift;
	my ($Sys, $Page) = @_;
	my ($Banner, %PATHES, @subDirs, @info, @dirs);
	my ($basePath, $path, $id, $dir, $key, $subj, $date);
	
	# mǂݍ
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($Sys);
	
	$basePath = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS');
	
	# pXL[ɂănbV쐬
	foreach $id (keys(%{$this->{'KEY'}})) {
		$path = $this->{'PATH'}->{$id};
		$PATHES{$path} = $id;
	}
	@dirs = keys %PATHES;
	unshift @dirs, '';
	
	# pXƂindex𐶐
	foreach $path (@dirs) {
		# 1Kw̃TutH_擾
		GetSubFolders($path, \@dirs, \@subDirs);
		foreach $dir (sort @subDirs) {
			push @info, "0<>0<>0<>$dir";
		}
		
		# Of[^Ώzɒǉ
		foreach $id (keys(%{$this->{'KEY'}})) {
			if ($path eq $this->{'PATH'}->{$id} && $this->{'KEY'}->{$id} ne '0') {
				$key = $this->{'KEY'}->{$id};
				$subj = $this->{'SUBJECT'}->{$id};
				$date = $this->{'DATE'}->{$id};
				push @info, "$key<>$subj<>$date<>$path";
			}
		}
		
		# indext@Co͂
		$Page->Clear();
		OutputIndex($Sys, $Page, $Banner, \@info, $basePath, $path);
		
		undef @info;
		undef @subDirs;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	TutH_擾
#	-------------------------------------------------------------------------------------
#	@param	$base	etH_pX
#	@param	$pDirs	fBNg̔z
#	@param	$pList	TutH_i[z
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub GetSubFolders
{
	my ($base, $pDirs, $pList) = @_;
	my ($dir, $old);
	
	$base .= '/';
	foreach $dir (@$pDirs) {
		$old = $dir;
		$old =~ s/^$base//;
		if ($old ne $dir && $old !~ /\//) {
			push @$pList, $old;
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋO^Cg̎擾
#	-------------------------------------------------------------------------------------
#	@param	$path	擾t@C̃pX
#	@return	^Cg
#
#------------------------------------------------------------------------------------------------------------
sub GetThreadSubject
{
	my ($path) = @_;
	my ($text);
	
	if (-e $path) {
		open FILE, "< $path";
		foreach $text (<FILE>) {
			if ($text =~ /<title>(.*)<\/title>/) {
				close FILE;
				return $1;
			}
		}
	}
	close FILE;
	return '';
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOindexo͂
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Page	THORIN
#	@param	$Banner	DENETHOR
#	@param	$pInfo	o͏z
#	@param	$base	fgbvpX
#	@param	$path	indexo̓pX
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub OutputIndex
{
	my ($Sys, $Page, $Banner, $pInfo, $base, $path, $Set) = @_;
	my (@elem, $info, $version);
	my ($Caption, $bbsRoot, $board, $cgipath);
	
	$cgipath	= $Sys->Get('CGIPATH');
	
	require './module/legolas.pl';
	$Caption = LEGOLAS->new;
	$Caption->Load($Sys, 'META');
	
	$version = $Sys->Get('VERSION');
	$bbsRoot = $Sys->Get('CGIPATH') . '/' . $Sys->Get('BBSPATH') . '/'. $Sys->Get('BBS');
	$board = $Sys->Get('BBS');
	
	$Page->Print(<<HTML);
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
<head>

 <meta http-equiv="Content-Type" content="text/html;charset=Shift_JIS">

HTML
	
	$Caption->Print($Page, undef);
	
	$Page->Print(<<HTML);
 <title>ߋOq - $board$path</title>

</head>
<!--nobanner-->
<body>
HTML
	
	# mo
	$Banner->Print($Page, 100, 2, 0);
	
	$Page->Print(<<HTML);

<h1 align="center" style="margin-bottom:0.2em;">ߋOq</h1>
<h2 align="center" style="margin-top:0.2em;">$board</h2>

<table border="1">
 <tr>
  <th>KEY</th>
  <th>subject</th>
  <th>date</th>
 </tr>
HTML
	
	foreach $info (@$pInfo) {
		@elem = split(/<>/, $info);
		
		# TutH_
		if ($elem[0] eq '0') {
			$Page->Print(" <tr>\n  <td>Directory</td>\n  <td><a href=\"$elem[3]/index.html\">");
			$Page->Print("$elem[3]</a></td>\n  <td>-</td>\n </tr>\n");
		}
		# ߋO
		else {
			$Page->Print(" <tr>\n  <td>$elem[0]</td>\n  <td><a href=\"$elem[0].html\">");
			$Page->Print("$elem[1]</a></td>\n  <td>$elem[2]</td>\n </tr>\n");
		}
	}
	$Page->Print("</table>\n\n<hr>\n");
	$Page->Print(<<HTML);

<a href="$bbsRoot/">fɖ߂遡</a> | <a href="$bbsRoot/kako/">ߋOgbvɖ߂遡</a> | <a href="../">1ɖ߂遡</a>

<hr>

<div align="right">
<a href="http://validator.w3.org/check?uri=referer"><img src="$cgipath/datas/html.gif" alt="Valid HTML 4.01 Transitional" height="15" width="80" border="0"></a>
$version
</div>
</body>
</html>
HTML
	
	# index.htmlo͂
	$Page->Flush(1, 0666, "$base/kako$path/index.html");
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;

==> zerochplus_0.6.1.tar.gz: zerochplus_0.6.1/test/module/celeborn.pl <==
#============================================================================================================
#
#	ߋOǗW[(CELEBORN)
#	celeborn.pl
#	-------------------------------------------------------------------------------------
#	2003.01.22 start
#	2003.03.07 Make\bhǉ
#	2004.08.24 č\z
#
#============================================================================================================
package	CELEBORN;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (%KAKO, $PATH, $obj);
	
	$obj = {
		'KEY'		=> undef,
		'SUBJECT'	=> undef,
		'DATE'		=> undef,
		'PATH'		=> undef
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOt@Cǂݍ
#	-------------------------------------------------------------------------------------
#	@param	$SYS	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($SYS) = @_;
	my (@elem, $path);
	
	undef $this->{'KEY'};
	undef $this->{'SUBJECT'};
	undef $this->{'DATE'};
	undef $this->{'PATH'};
	
	$path = $SYS->Get('BBSPATH') . '/' . $SYS->Get('BBS') . '/kako/kako.idx';
	
	if (-e $path) {
		open KAKO, "< $path";
		while (<KAKO>) {
			chomp $_;
			@elem = split(/<>/, $_);
			$this->{'KEY'}->{$elem[0]}		= $elem[1];
			$this->{'SUBJECT'}->{$elem[0]}	= $elem[2];
			$this->{'DATE'}->{$elem[0]}		= $elem[3];
			$this->{'PATH'}->{$elem[0]}		= $elem[4];
		}
		close KAKO;
		return 0;
	}
	return -1;
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOt@C
#	-------------------------------------------------------------------------------------
#	@param	$SYS	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($SYS) = @_;
	my ($path, $data);
	
	$path = $SYS->Get('BBSPATH') . '/' . $SYS->Get('BBS') . '/kako/kako.idx';
	
#	eval
	{
		open KAKO, "> $path";
		flock KAKO, 2;
		binmode KAKO;
		#truncate KAKO, 0;
		#seek KAKO, 0, 0;
		foreach (keys %{$this->{'SUBJECT'}}) {
			$data = join('<>',
				$_,
				$this->{KEY}->{$_},
				$this->{SUBJECT}->{$_},
				$this->{DATE}->{$_},
				$this->{PATH}->{$_}
			);
			
			print KAKO "$data\n";
		}
		close KAKO;
		chmod $SYS->Get('PM-DAT'), $path;
	};
}

#------------------------------------------------------------------------------------------------------------
#
#	IDZbg擾
#	-------------------------------------------------------------------------------------
#	@param	$kind	
#	@param	$name	[h
#	@param	$pBuf	IDZbgi[obt@
#	@return	L[Zbg
#
#------------------------------------------------------------------------------------------------------------
sub GetKeySet
{
	my $this = shift;
	my ($kind, $name, $pBuf) = @_;
	my ($key, $n);
	
	$n = 0;
	
	if ($kind eq 'ALL') {
		foreach $key (keys %{$this->{'KEY'}}) {
			if ($this->{'KEY'}->{$key} ne '0') {
				push @$pBuf, $key;
				$n++;
			}
		}
	}
	else {
		foreach $key (keys %{$this->{$kind}}) {
			if ($this->{$kind}->{$key} eq $name || $kind eq 'ALL') {
				push @$pBuf, $key;
				$n++;
			}
		}
	}
	
	return $n;
}

#------------------------------------------------------------------------------------------------------------
#
#	擾
#	-------------------------------------------------------------------------------------
#	@param	$kind	
#	@param	$key	[UID
#			$default : ftHg
#	@return	[U
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($kind, $key, $default) = @_;
	my ($val);
	
	$val = $this->{$kind}->{$key};
	
	return (defined $val ? $val : (defined $default ? $default : undef));
}

#------------------------------------------------------------------------------------------------------------
#
#	ǉ
#	-------------------------------------------------------------------------------------
#	@param	$key		XbhL[
#	@param	$subject	Xbh^Cg
#	@param	$date		XV
#	@return	ID
#
#------------------------------------------------------------------------------------------------------------
sub Add
{
	my $this = shift;
	my ($key, $subject, $date, $path) = @_;
	my ($id);
	
	$id = time;
	while (exists $this->{'KEY'}->{$id}) {
		$id++;
	}
	$this->{'KEY'}->{$id}		= $key;
	$this->{'SUBJECT'}->{$id}	= $subject;
	$this->{'DATE'}->{$id}		= $date;
	$this->{'PATH'}->{$id}		= $path;
	
	return $id;
}

#------------------------------------------------------------------------------------------------------------
#
#	ݒ
#	-------------------------------------------------------------------------------------
#	@param	$id		ID
#	@param	$kind	
#	@param	$val	ݒl
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($id, $kind, $val) = @_;
	
	if (exists $this->{$kind}->{$id}) {
		$this->{$kind}->{$id} = $val;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	폜
#	-------------------------------------------------------------------------------------
#	@param	$id		폜ID
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Delete
{
	my $this = shift;
	my ($id) = @_;
	
	delete $this->{'KEY'}->{$id};
	delete $this->{'SUBJECT'}->{$id};
	delete $this->{'DATE'}->{$id};
	delete $this->{'PATH'}->{$id};
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋO̍XV
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub UpdateInfo
{
	my $this = shift;
	my ($Sys) = @_;
	my (%Dirs, @dirList, @fileList, @elem);
	my ($dir, $file, $path, $subj);
	
	require './module/earendil.pl';
	
	undef $this->{'KEY'};
	undef $this->{'SUBJECT'};
	undef $this->{'DATE'};
	undef $this->{'PATH'};
	
	$path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . '/kako';
	
	# fBNg擾
	EARENDIL::GetFolderHierarchy($path, \%Dirs);
	EARENDIL::GetFolderList(\%Dirs, \@dirList, '');
	
	foreach $dir (@dirList) {
		EARENDIL::GetFileList("$path/$dir", \@fileList, '(\d+)\.html');
		Add($this, 0, 0, 0, $dir);
		foreach $file (@fileList) {
			@elem = split(/\./, $file);
			$subj = GetThreadSubject("$path/$dir/$file");
			if ($subj ne '') {
				Add($this, $elem[0], $subj, time, $dir);
			}
		}
		undef @fileList;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOindex̍XV
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub UpdateIndex
{
	my $this = shift;
	my ($Sys, $Page) = @_;
	my ($Banner, %PATHES, @subDirs, @info, @dirs);
	my ($basePath, $path, $id, $dir, $key, $subj, $date);
	
	# mǂݍ
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($Sys);
	
	$basePath = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS');
	
	# pXL[ɂănbV쐬
	foreach $id (keys(%{$this->{'KEY'}})) {
		$path = $this->{'PATH'}->{$id};
		$PATHES{$path} = $id;
	}
	@dirs = keys %PATHES;
	unshift @dirs, '';
	
	# pXƂindex𐶐
	foreach $path (@dirs) {
		# 1Kw̃TutH_擾
		GetSubFolders($path, \@dirs, \@subDirs);
		foreach $dir (sort @subDirs) {
			push @info, "0<>0<>0<>$dir";
		}
		
		# Of[^Ώzɒǉ
		foreach $id (keys(%{$this->{'KEY'}})) {
			if ($path eq $this->{'PATH'}->{$id} && $this->{'KEY'}->{$id} ne '0') {
				$key = $this->{'KEY'}->{$id};
				$subj = $this->{'SUBJECT'}->{$id};
				$date = $this->{'DATE'}->{$id};
				push @info, "$key<>$subj<>$date<>$path";
			}
		}
		
		# indext@Co͂
		$Page->Clear();
		OutputIndex($Sys, $Page, $Banner, \@info, $basePath, $path);
		
		undef @info;
		undef @subDirs;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	TutH_擾
#	-------------------------------------------------------------------------------------
#	@param	$base	etH_pX
#	@param	$pDirs	fBNg̔z
#	@param	$pList	TutH_i[z
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub GetSubFolders
{
	my ($base, $pDirs, $pList) = @_;
	my ($dir, $old);
	
	$base .= '/';
	foreach $dir (@$pDirs) {
		$old = $dir;
		$old =~ s/^$base//;
		if ($old ne $dir && $old !~ /\//) {
			push @$pList, $old;
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋO^Cg̎擾
#	-------------------------------------------------------------------------------------
#	@param	$path	擾t@C̃pX
#	@return	^Cg
#
#------------------------------------------------------------------------------------------------------------
sub GetThreadSubject
{
	my ($path) = @_;
	my ($text);
	
	if (-e $path) {
		open FILE, "< $path";
		foreach $text (<FILE>) {
			if ($text =~ /<title>(.*)<\/title>/) {
				close FILE;
				return $1;
			}
		}
	}
	close FILE;
	return '';
}

#------------------------------------------------------------------------------------------------------------
#
#	ߋOindexo͂
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Page	THORIN
#	@param	$Banner	DENETHOR
#	@param	$pInfo	o͏z
#	@param	$base	fgbvpX
#	@param	$path	indexo̓pX
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub OutputIndex
{
	my ($Sys, $Page, $Banner, $pInfo, $base, $path, $Set) = @_;
	my (@elem, $info, $version);
	my ($Caption, $bbsRoot, $board, $cgipath);
	
	$cgipath	= $Sys->Get('CGIPATH');
	
	require './module/legolas.pl';
	$Caption = LEGOLAS->new;
	$Caption->Load($Sys, 'META');
	
	$version = $Sys->Get('VERSION');
	$bbsRoot = $Sys->Get('CGIPATH') . '/' . $Sys->Get('BBSPATH') . '/'. $Sys->Get('BBS');
	$board = $Sys->Get('BBS');
	
	$Page->Print(<<HTML);
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
<head>

 <meta http-equiv="Content-Type" content="text/html;charset=Shift_JIS">

HTML
	
	$Caption->Print($Page, undef);
	
	$Page->Print(<<HTML);
 <title>ߋOq - $board$path</title>

</head>
<!--nobanner-->
<body>
HTML
	
	# mo
	$Banner->Print($Page, 100, 2, 0);
	
	$Page->Print(<<HTML);

<h1 align="center" style="margin-bottom:0.2em;">ߋOq</h1>
<h2 align="center" style="margin-top:0.2em;">$board</h2>

<table border="1">
 <tr>
  <th>KEY</th>
  <th>subject</th>
  <th>date</th>
 </tr>
HTML
	
	foreach $info (@$pInfo) {
		@elem = split(/<>/, $info);
		
		# TutH_
		if ($elem[0] eq '0') {
			$Page->Print(" <tr>\n  <td>Directory</td>\n  <td><a href=\"$elem[3]/\">");
			$Page->Print("$elem[3]</a></td>\n  <td>-</td>\n </tr>\n");
		}
		# ߋO
		else {
			$Page->Print(" <tr>\n  <td>$elem[0]</td>\n  <td><a href=\"$elem[0].html\">");
			$Page->Print("$elem[1]</a></td>\n  <td>$elem[2]</td>\n </tr>\n");
		}
	}
	$Page->Print("</table>\n\n<hr>\n");
	$Page->Print(<<HTML);

<a href="$bbsRoot/">fɖ߂遡</a> | <a href="$bbsRoot/kako/">ߋOgbvɖ߂遡</a> | <a href="../">1ɖ߂遡</a>

<hr>

<div align="right">
<a href="http://validator.w3.org/check?uri=referer"><img src="$cgipath/datas/html.gif" alt="Valid HTML 4.01 Transitional" height="15" width="80" border="0"></a>
$version
</div>
</body>
</html>
HTML
	
	# index.htmlo͂
	$Page->Flush(1, 0666, "$base/kako$path/index.html");
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;
